==> MacUIM-0.2.3.1.tar.bz2: MacUIM-0.2.3.1/Debug.h <==
/* -*- mode:c; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
/*
  Copyright (c) 2004 MacUIM Project
  http://www.digital-genes.com/~yatsu/macuim/

  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:

  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  SUCH DAMAGE.
*/

#ifndef DEBUG_h
#define DEBUG_h

#ifndef DEBUG
#define DEBUG  0
#endif

#ifndef DEBUG_INPUT_EVENT
#define DEBUG_INPUT_EVENT  0
#endif

#ifndef DEBUG_PREEDIT
#define DEBUG_PREEDIT  0
#endif

#ifndef DEBUG_HELPER
#define DEBUG_HELPER  0
#endif

#ifndef DEBUG_CANDIDATES
#define DEBUG_CANDIDATES  0
#endif

#ifndef DEBUG_KEYEVENT
#define DEBUG_KEYEVENT  0
#endif

#ifndef DEBUG_MENU
#define DEBUG_MENU  0
#endif

#ifndef DEBUG_CANDIDATES
#define DEBUG_CANDIDATES  0
#endif

#ifndef DEBUG_SESSION
#define DEBUG_SESSION  0
#endif

#ifndef DEBUG_UIM
#define DEBUG_UIM  0
#endif

#ifndef DEBUG_PRIME
#define DEBUG_PRIME  0
#endif

#endif // Debug_h

==> MacUIM-0.2.6.tar.bz2: MacUIM-0.2.6/Debug.h <==
/* -*- mode:c; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
/*
  Copyright (c) 2004 MacUIM Project
  http://www.digital-genes.com/~yatsu/macuim/

  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:

  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  SUCH DAMAGE.
*/

#ifndef DEBUG_h
#define DEBUG_h

#ifndef DEBUG
#define DEBUG  0
#endif

#ifndef DEBUG_INPUT_EVENT
#define DEBUG_INPUT_EVENT  0
#endif

#ifndef DEBUG_PREEDIT
#define DEBUG_PREEDIT  0
#endif

#ifndef DEBUG_HELPER
#define DEBUG_HELPER  0
#endif

#ifndef DEBUG_HELPER_EXTRA
#define DEBUG_HELPER_EXTRA  0
#endif

#ifndef DEBUG_CANDIDATES
#define DEBUG_CANDIDATES  0
#endif

#ifndef DEBUG_KEYEVENT
#define DEBUG_KEYEVENT  0
#endif

#ifndef DEBUG_MENU
#define DEBUG_MENU  0
#endif

#ifndef DEBUG_CANDIDATES
#define DEBUG_CANDIDATES  0
#endif

#ifndef DEBUG_SESSION
#define DEBUG_SESSION  0
#endif

#ifndef DEBUG_COMPONENT
#define DEBUG_COMPONENT  0
#endif

#ifndef DEBUG_NOTIFY
#define DEBUG_NOTIFY  0
#endif

#ifndef DEBUG_UIM
#define DEBUG_UIM  0
#endif

#ifndef DEBUG_PRIME
#define DEBUG_PRIME  0
#endif

#endif // Debug_h
